@@ -97,7 +97,8 @@ const CharacterListWidget = new Lang.Class({
         this._fontDescription = filtered.fontDescription;
         this._characters = [];
         this._rows = [];
-        this.add_events(Gdk.EventMask.BUTTON_PRESS_MASK);
+        this.add_events(Gdk.EventMask.BUTTON_PRESS_MASK |
+                        Gdk.EventMask.BUTTON_RELEASE_MASK);
     },
 
     vfunc_button_press_event: function(event) {
@@ -176,6 +177,7 @@ const CharacterListWidget = new Lang.Class({
             this._rows.push(row);
         }
 
+        this.queue_resize();
         this.queue_draw();
     },
 
@@ -242,7 +244,10 @@ const CharacterListView = new Lang.Class({
     },
 
     _init: function(params) {
-        params = Params.fill(params, { hexpand: true, vexpand: true });
+        params = Params.fill(params, {
+            hexpand: true, vexpand: true,
+            transition_type: Gtk.StackTransitionType.CROSSFADE
+        });
         this.parent(params);
 
         Main.settings.bind('font', this, 'font', Gio.SettingsBindFlags.DEFAULT);
@@ -251,10 +256,12 @@ const CharacterListView = new Lang.Class({
                                                         vexpand: true,
                                                         fontDescription: this._fontDescription });
         let scroll = new Gtk.ScrolledWindow({
-            hscrollbar_policy: Gtk.PolicyType.NEVER
+            hscrollbar_policy: Gtk.PolicyType.NEVER,
+            visible: true
         });
         scroll.add(this._characterList);
         this.add_named(scroll, 'character-list');
+        this.visible_child_name = 'character-list';
 
         this._characters = [];
         this._spinnerTimeoutId = 0;
